@@ -13,18 +13,24 @@
 """Placeholder docstring"""
 from __future__ import absolute_import
 
-from sagemaker.amazon.amazon_estimator import AmazonAlgorithmEstimatorBase, registry
-from sagemaker.amazon.common import numpy_to_record_serializer, record_deserializer
+from sagemaker import image_uris
+from sagemaker.amazon.amazon_estimator import AmazonAlgorithmEstimatorBase
+from sagemaker.amazon.common import RecordSerializer, RecordDeserializer
 from sagemaker.amazon.hyperparameter import Hyperparameter as hp  # noqa
 from sagemaker.amazon.validation import ge, isin
-from sagemaker.predictor import RealTimePredictor
+from sagemaker.predictor import Predictor
 from sagemaker.model import Model
 from sagemaker.session import Session
 from sagemaker.vpc_utils import VPC_CONFIG_DEFAULT
 
 
 class KNN(AmazonAlgorithmEstimatorBase):
-    """Placeholder docstring"""
+    """An index-based algorithm. It uses a non-parametric method for classification or regression.
+
+    For classification problems, the algorithm queries the k points that are closest to the sample
+    point and returns the most frequently used label of their class as the predicted label. For
+    regression problems, the algorithm queries the k closest points to the sample point and returns
+    the average of their feature values as the predicted value."""
 
     repo_name = "knn"
     repo_version = 1
@@ -63,8 +69,8 @@ class KNN(AmazonAlgorithmEstimatorBase):
     def __init__(
         self,
         role,
-        train_instance_count,
-        train_instance_type,
+        instance_count,
+        instance_type,
         k,
         sample_size,
         predictor_type,
@@ -105,8 +111,8 @@ class KNN(AmazonAlgorithmEstimatorBase):
                 endpoints use this role to access training data and model
                 artifacts. After the endpoint is created, the inference code
                 might use the IAM role, if accessing AWS resource.
-            train_instance_count:
-            train_instance_type (str): Type of EC2 instance to use for training,
+            instance_count:
+            instance_type (str): Type of EC2 instance to use for training,
                 for example, 'ml.c4.xlarge'.
             k (int): Required. Number of nearest neighbors.
             sample_size (int): Required. Number of data points to be sampled
@@ -136,7 +142,7 @@ class KNN(AmazonAlgorithmEstimatorBase):
             :class:`~sagemaker.estimator.EstimatorBase`.
         """
 
-        super(KNN, self).__init__(role, train_instance_count, train_instance_type, **kwargs)
+        super(KNN, self).__init__(role, instance_count, instance_type, **kwargs)
         self.k = k
         self.sample_size = sample_size
         self.predictor_type = predictor_type
@@ -182,12 +188,12 @@ class KNN(AmazonAlgorithmEstimatorBase):
         )
 
 
-class KNNPredictor(RealTimePredictor):
+class KNNPredictor(Predictor):
     """Performs classification or regression prediction from input vectors.
 
     The implementation of
-    :meth:`~sagemaker.predictor.RealTimePredictor.predict` in this
-    `RealTimePredictor` requires a numpy ``ndarray`` as input. The array should
+    :meth:`~sagemaker.predictor.Predictor.predict` in this
+    `Predictor` requires a numpy ``ndarray`` as input. The array should
     contain the same number of columns as the feature-dimension of the data used
     to fit the model this Predictor performs inference on.
 
@@ -197,17 +203,21 @@ class KNNPredictor(RealTimePredictor):
     key of the ``Record.label`` field.
     """
 
-    def __init__(self, endpoint, sagemaker_session=None):
+    def __init__(self, endpoint_name, sagemaker_session=None):
         """
         Args:
-            endpoint:
-            sagemaker_session:
+            endpoint_name (str): Name of the Amazon SageMaker endpoint to which
+                requests are sent.
+            sagemaker_session (sagemaker.session.Session): A SageMaker Session
+                object, used for SageMaker interactions (default: None). If not
+                specified, one is created using the default AWS configuration
+                chain.
         """
         super(KNNPredictor, self).__init__(
-            endpoint,
+            endpoint_name,
             sagemaker_session,
-            serializer=numpy_to_record_serializer(),
-            deserializer=record_deserializer(),
+            serializer=RecordSerializer(),
+            deserializer=RecordDeserializer(),
         )
 
 
@@ -220,19 +230,29 @@ class KNNModel(Model):
     def __init__(self, model_data, role, sagemaker_session=None, **kwargs):
         """
         Args:
-            model_data:
-            role:
-            sagemaker_session:
-            **kwargs:
+            model_data (str): The S3 location of a SageMaker model data
+                ``.tar.gz`` file.
+            role (str): An AWS IAM role (either name or full ARN). The Amazon
+                SageMaker training jobs and APIs that create Amazon SageMaker
+                endpoints use this role to access training data and model
+                artifacts. After the endpoint is created, the inference code
+                might use the IAM role, if it needs to access an AWS resource.
+            sagemaker_session (sagemaker.session.Session): Session object which
+                manages interactions with Amazon SageMaker APIs and any other
+                AWS services needed. If not specified, the estimator creates one
+                using the default AWS configuration chain.
+            **kwargs: Keyword arguments passed to the ``FrameworkModel``
+                initializer.
         """
         sagemaker_session = sagemaker_session or Session()
-        repo = "{}:{}".format(KNN.repo_name, KNN.repo_version)
-        image = "{}/{}".format(
-            registry(sagemaker_session.boto_session.region_name, KNN.repo_name), repo
+        image_uri = image_uris.retrieve(
+            KNN.repo_name,
+            sagemaker_session.boto_region_name,
+            version=KNN.repo_version,
         )
         super(KNNModel, self).__init__(
+            image_uri,
             model_data,
-            image,
             role,
             predictor_cls=KNNPredictor,
             sagemaker_session=sagemaker_session,
