@@ -13,18 +13,23 @@
 """Placeholder docstring"""
 from __future__ import absolute_import
 
-from sagemaker.amazon.amazon_estimator import AmazonAlgorithmEstimatorBase, registry
-from sagemaker.amazon.common import numpy_to_record_serializer, record_deserializer
+from sagemaker import image_uris
+from sagemaker.amazon.amazon_estimator import AmazonAlgorithmEstimatorBase
+from sagemaker.amazon.common import RecordSerializer, RecordDeserializer
 from sagemaker.amazon.hyperparameter import Hyperparameter as hp  # noqa
 from sagemaker.amazon.validation import ge, le, isin
-from sagemaker.predictor import RealTimePredictor
+from sagemaker.predictor import Predictor
 from sagemaker.model import Model
 from sagemaker.session import Session
 from sagemaker.vpc_utils import VPC_CONFIG_DEFAULT
 
 
 class NTM(AmazonAlgorithmEstimatorBase):
-    """Placeholder docstring"""
+    """An unsupervised learning algorithm used to organize a corpus of documents into topics
+
+    The resulting topics contain word groupings based on their statistical distribution.
+    Documents that contain frequent occurrences of words such as "bike", "car", "train",
+    "mileage", and "speed" are likely to share a topic on "transportation" for example."""
 
     repo_name = "ntm"
     repo_version = 1
@@ -59,8 +64,8 @@ class NTM(AmazonAlgorithmEstimatorBase):
     def __init__(
         self,
         role,
-        train_instance_count,
-        train_instance_type,
+        instance_count,
+        instance_type,
         num_topics,
         encoder_layers=None,
         epochs=None,
@@ -113,8 +118,8 @@ class NTM(AmazonAlgorithmEstimatorBase):
                 endpoints use this role to access training data and model
                 artifacts. After the endpoint is created, the inference code
                 might use the IAM role, if accessing AWS resource.
-            train_instance_count:
-            train_instance_type (str): Type of EC2 instance to use for training,
+            instance_count:
+            instance_type (str): Type of EC2 instance to use for training,
                 for example, 'ml.c4.xlarge'.
             num_topics (int): Required. The number of topics for NTM to find
                 within the data.
@@ -147,7 +152,7 @@ class NTM(AmazonAlgorithmEstimatorBase):
             :class:`~sagemaker.estimator.EstimatorBase`.
         """
 
-        super(NTM, self).__init__(role, train_instance_count, train_instance_type, **kwargs)
+        super(NTM, self).__init__(role, instance_count, instance_type, **kwargs)
         self.num_topics = num_topics
         self.encoder_layers = encoder_layers
         self.epochs = epochs
@@ -196,12 +201,12 @@ class NTM(AmazonAlgorithmEstimatorBase):
         )
 
 
-class NTMPredictor(RealTimePredictor):
+class NTMPredictor(Predictor):
     """Transforms input vectors to lower-dimesional representations.
 
     The implementation of
-    :meth:`~sagemaker.predictor.RealTimePredictor.predict` in this
-    `RealTimePredictor` requires a numpy ``ndarray`` as input. The array should
+    :meth:`~sagemaker.predictor.Predictor.predict` in this
+    `Predictor` requires a numpy ``ndarray`` as input. The array should
     contain the same number of columns as the feature-dimension of the data used
     to fit the model this Predictor performs inference on.
 
@@ -211,17 +216,21 @@ class NTMPredictor(RealTimePredictor):
     ``projection`` key of the ``Record.label`` field.
     """
 
-    def __init__(self, endpoint, sagemaker_session=None):
+    def __init__(self, endpoint_name, sagemaker_session=None):
         """
         Args:
-            endpoint:
-            sagemaker_session:
+            endpoint_name (str): Name of the Amazon SageMaker endpoint to which
+                requests are sent.
+            sagemaker_session (sagemaker.session.Session): A SageMaker Session
+                object, used for SageMaker interactions (default: None). If not
+                specified, one is created using the default AWS configuration
+                chain.
         """
         super(NTMPredictor, self).__init__(
-            endpoint,
+            endpoint_name,
             sagemaker_session,
-            serializer=numpy_to_record_serializer(),
-            deserializer=record_deserializer(),
+            serializer=RecordSerializer(),
+            deserializer=RecordDeserializer(),
         )
 
 
@@ -234,19 +243,29 @@ class NTMModel(Model):
     def __init__(self, model_data, role, sagemaker_session=None, **kwargs):
         """
         Args:
-            model_data:
-            role:
-            sagemaker_session:
-            **kwargs:
+            model_data (str): The S3 location of a SageMaker model data
+                ``.tar.gz`` file.
+            role (str): An AWS IAM role (either name or full ARN). The Amazon
+                SageMaker training jobs and APIs that create Amazon SageMaker
+                endpoints use this role to access training data and model
+                artifacts. After the endpoint is created, the inference code
+                might use the IAM role, if it needs to access an AWS resource.
+            sagemaker_session (sagemaker.session.Session): Session object which
+                manages interactions with Amazon SageMaker APIs and any other
+                AWS services needed. If not specified, the estimator creates one
+                using the default AWS configuration chain.
+            **kwargs: Keyword arguments passed to the ``FrameworkModel``
+                initializer.
         """
         sagemaker_session = sagemaker_session or Session()
-        repo = "{}:{}".format(NTM.repo_name, NTM.repo_version)
-        image = "{}/{}".format(
-            registry(sagemaker_session.boto_session.region_name, NTM.repo_name), repo
+        image_uri = image_uris.retrieve(
+            NTM.repo_name,
+            sagemaker_session.boto_region_name,
+            version=NTM.repo_version,
         )
         super(NTMModel, self).__init__(
+            image_uri,
             model_data,
-            image,
             role,
             predictor_cls=NTMPredictor,
             sagemaker_session=sagemaker_session,
