@@ -26,8 +26,7 @@ logger = logging.getLogger("sagemaker")
 
 
 class AutoML(object):
-    """A class for creating and interacting with SageMaker AutoML jobs
-    """
+    """A class for creating and interacting with SageMaker AutoML jobs"""
 
     def __init__(
         self,
@@ -307,12 +306,12 @@ class AutoML(object):
         models = []
 
         for container in inference_containers:
-            image = container["Image"]
+            image_uri = container["Image"]
             model_data = container["ModelDataUrl"]
             env = container["Environment"]
 
             model = Model(
-                image=image,
+                image_uri=image_uri,
                 model_data=model_data,
                 role=self.role,
                 env=env,
@@ -337,13 +336,14 @@ class AutoML(object):
         self,
         initial_instance_count,
         instance_type,
+        serializer=None,
+        deserializer=None,
         candidate=None,
         sagemaker_session=None,
         name=None,
         endpoint_name=None,
         tags=None,
         wait=True,
-        update_endpoint=False,
         vpc_config=None,
         enable_network_isolation=False,
         model_kms_key=None,
@@ -357,6 +357,16 @@ class AutoML(object):
                 in the ``Endpoint`` created from this ``Model``.
             instance_type (str): The EC2 instance type to deploy this Model to.
                 For example, 'ml.p2.xlarge'.
+            serializer (:class:`~sagemaker.serializers.BaseSerializer`): A
+                serializer object, used to encode data for an inference endpoint
+                (default: None). If ``serializer`` is not None, then
+                ``serializer`` will override the default serializer. The
+                default serializer is set by the ``predictor_cls``.
+            deserializer (:class:`~sagemaker.deserializers.BaseDeserializer`): A
+                deserializer object, used to decode data from an inference
+                endpoint (default: None). If ``deserializer`` is not None, then
+                ``deserializer`` will override the default deserializer. The
+                default deserializer is set by the ``predictor_cls``.
             candidate (CandidateEstimator or dict): a CandidateEstimator used for deploying
                 to a SageMaker Inference Pipeline. If None, the best candidate will
                 be used. If the candidate input is a dict, a CandidateEstimator will be
@@ -372,11 +382,6 @@ class AutoML(object):
                 specific endpoint.
             wait (bool): Whether the call should wait until the deployment of
                 model completes (default: True).
-            update_endpoint (bool): Flag to update the model in an existing
-                Amazon SageMaker endpoint. If True, this will deploy a new
-                EndpointConfig to an already existing endpoint and delete
-                resources corresponding to the previous EndpointConfig. If
-                False, a new endpoint will be created. Default: False
             vpc_config (dict): Specifies a VPC that your training jobs and hosted models have
                 access to. Contents include "SecurityGroupIds" and "Subnets".
             enable_network_isolation (bool): Isolates the training container. No inbound or
@@ -411,10 +416,11 @@ class AutoML(object):
         return model.deploy(
             initial_instance_count=initial_instance_count,
             instance_type=instance_type,
+            serializer=serializer,
+            deserializer=deserializer,
             endpoint_name=endpoint_name,
             tags=tags,
             wait=wait,
-            update_endpoint=update_endpoint,
         )
 
     def _check_problem_type_and_job_objective(self, problem_type, job_objective):
