@@ -13,15 +13,11 @@
 """Amazon SageMaker channel configurations for S3 data sources and file system data sources"""
 from __future__ import absolute_import, print_function
 
-import logging
-
 FILE_SYSTEM_TYPES = ["FSxLustre", "EFS"]
 FILE_SYSTEM_ACCESS_MODES = ["ro", "rw"]
 
-logger = logging.getLogger("sagemaker")
 
-
-class s3_input(object):
+class TrainingInput(object):
     """Amazon SageMaker channel configurations for S3 data sources.
 
     Attributes:
@@ -76,14 +72,10 @@ class s3_input(object):
                 found in a specified AugmentedManifestFile.
             target_attribute_name (str): The name of the attribute will be predicted (classified)
                 in a SageMaker AutoML job. It is required if the input is for SageMaker AutoML job.
-            shuffle_config (ShuffleConfig): If specified this configuration enables shuffling on
-                this channel. See the SageMaker API documentation for more info:
+            shuffle_config (sagemaker.inputs.ShuffleConfig): If specified this configuration enables
+                shuffling on this channel. See the SageMaker API documentation for more info:
                 https://docs.aws.amazon.com/sagemaker/latest/dg/API_ShuffleConfig.html
         """
-        logger.warning(
-            "'s3_input' class will be renamed to 'TrainingInput' in SageMaker Python SDK v2."
-        )
-
         self.config = {
             "DataSource": {"S3DataSource": {"S3DataType": s3_data_type, "S3Uri": s3_data}}
         }
@@ -110,6 +102,22 @@ class s3_input(object):
             self.config["ShuffleConfig"] = {"Seed": shuffle_config.seed}
 
 
+class ShuffleConfig(object):
+    """For configuring channel shuffling using a seed.
+
+    For more detail, see the AWS documentation:
+    https://docs.aws.amazon.com/sagemaker/latest/dg/API_ShuffleConfig.html
+    """
+
+    def __init__(self, seed):
+        """Create a ShuffleConfig.
+
+        Args:
+            seed (long): the long value used to seed the shuffled sequence.
+        """
+        self.seed = seed
+
+
 class FileSystemInput(object):
     """Amazon SageMaker channel configurations for file system data sources.
 
