@@ -19,6 +19,8 @@ import shutil
 from distutils.dir_util import copy_tree
 from six.moves.urllib.parse import urlparse
 
+from sagemaker import s3
+
 
 def copy_directory_structure(destination_directory, relative_path):
     """Create all the intermediate directories required for relative_path to
@@ -62,8 +64,8 @@ def move_to_destination(source, destination, job_name, sagemaker_session):
         final_uri = destination
     elif parsed_uri.scheme == "s3":
         bucket = parsed_uri.netloc
-        path = _create_s3_prefix(parsed_uri.path, job_name)
-        final_uri = "s3://%s/%s" % (bucket, path)
+        path = s3.s3_path_join(parsed_uri.path, job_name)
+        final_uri = s3.s3_path_join("s3://", bucket, path)
         sagemaker_session.upload_data(source, bucket, path)
     else:
         raise ValueError("Invalid destination URI, must be s3:// or file://, got: %s" % destination)
@@ -72,22 +74,6 @@ def move_to_destination(source, destination, job_name, sagemaker_session):
     return final_uri
 
 
-def _create_s3_prefix(path, job_name):
-    """Constructs a path out of the given path and job name to be
-    used as an S3 prefix.
-
-    Args:
-        path (str): the original path. If the path is only ``"/"``,
-            then it is ignored.
-        job_name (str): the job name to be appended to the path.
-
-    Returns:
-        str: an S3 prefix of the form ``"path/job_name"``
-    """
-    path = path.strip("/")
-    return job_name if path == "" else "/".join((path, job_name))
-
-
 def recursive_copy(source, destination):
     """A wrapper around distutils.dir_util.copy_tree but won't throw any
     exception when the source directory does not exist.
