@@ -18,21 +18,23 @@ import logging
 import packaging.version
 
 import sagemaker
+from sagemaker import image_uris
+from sagemaker.deserializers import JSONDeserializer
 from sagemaker.fw_utils import (
-    create_image_uri,
     model_code_key_prefix,
     python_deprecation_warning,
-    empty_framework_version_warning,
+    validate_version_or_image_args,
 )
 from sagemaker.model import FrameworkModel, MODEL_SERVER_WORKERS_PARAM_NAME
 from sagemaker.mxnet import defaults
-from sagemaker.predictor import RealTimePredictor, json_serializer, json_deserializer
+from sagemaker.predictor import Predictor
+from sagemaker.serializers import JSONSerializer
 
 logger = logging.getLogger("sagemaker")
 
 
-class MXNetPredictor(RealTimePredictor):
-    """A RealTimePredictor for inference against MXNet Endpoints.
+class MXNetPredictor(Predictor):
+    """A Predictor for inference against MXNet Endpoints.
 
     This is able to serialize Python lists, dictionaries, and numpy arrays to
     multidimensional tensors for MXNet inference.
@@ -50,14 +52,14 @@ class MXNetPredictor(RealTimePredictor):
                 using the default AWS configuration chain.
         """
         super(MXNetPredictor, self).__init__(
-            endpoint_name, sagemaker_session, json_serializer, json_deserializer
+            endpoint_name, sagemaker_session, JSONSerializer(), JSONDeserializer()
         )
 
 
 class MXNetModel(FrameworkModel):
     """An MXNet SageMaker ``Model`` that can be deployed to a SageMaker ``Endpoint``."""
 
-    __framework_name__ = "mxnet"
+    _framework_name = "mxnet"
     _LOWEST_MMS_VERSION = "1.4.0"
 
     def __init__(
@@ -65,9 +67,9 @@ class MXNetModel(FrameworkModel):
         model_data,
         role,
         entry_point,
-        image=None,
-        py_version="py2",
         framework_version=None,
+        py_version=None,
+        image_uri=None,
         predictor_cls=MXNetPredictor,
         model_server_workers=None,
         **kwargs
@@ -86,12 +88,18 @@ class MXNetModel(FrameworkModel):
                 file which should be executed as the entry point to model
                 hosting. If ``source_dir`` is specified, then ``entry_point``
                 must point to a file located at the root of ``source_dir``.
-            image (str): A Docker image URI (default: None). If not specified, a
-                default image for MXNet will be used.
-            py_version (str): Python version you want to use for executing your
-                model training code (default: 'py2').
             framework_version (str): MXNet version you want to use for executing
-                your model training code.
+                your model training code. Defaults to ``None``. Required unless
+                ``image_uri`` is provided.
+            py_version (str): Python version you want to use for executing your
+                model training code. Defaults to ``None``. Required unless
+                ``image_uri`` is provided.
+            image_uri (str): A Docker image URI (default: None). If not specified, a
+                default image for MXNet will be used.
+
+                If ``framework_version`` or ``py_version`` are ``None``, then
+                ``image_uri`` is required. If also ``None``, then a ``ValueError``
+                will be raised.
             predictor_cls (callable[str, sagemaker.session.Session]): A function
                 to call to create a predictor with an endpoint name and
                 SageMaker ``Session``. If specified, ``deploy()`` returns the
@@ -108,22 +116,18 @@ class MXNetModel(FrameworkModel):
             :class:`~sagemaker.model.FrameworkModel` and
             :class:`~sagemaker.model.Model`.
         """
-        super(MXNetModel, self).__init__(
-            model_data, image, role, entry_point, predictor_cls=predictor_cls, **kwargs
-        )
-
+        validate_version_or_image_args(framework_version, py_version, image_uri)
         if py_version == "py2":
             logger.warning(
-                python_deprecation_warning(self.__framework_name__, defaults.LATEST_PY2_VERSION)
+                python_deprecation_warning(self._framework_name, defaults.LATEST_PY2_VERSION)
             )
-
-        if framework_version is None:
-            logger.warning(
-                empty_framework_version_warning(defaults.MXNET_VERSION, defaults.LATEST_VERSION)
-            )
-
+        self.framework_version = framework_version
         self.py_version = py_version
-        self.framework_version = framework_version or defaults.MXNET_VERSION
+
+        super(MXNetModel, self).__init__(
+            model_data, image_uri, role, entry_point, predictor_cls=predictor_cls, **kwargs
+        )
+
         self.model_server_workers = model_server_workers
 
     def prepare_container_def(self, instance_type=None, accelerator_type=None):
@@ -141,7 +145,7 @@ class MXNetModel(FrameworkModel):
             dict[str, str]: A container definition object usable with the
             CreateModel API.
         """
-        deploy_image = self.image
+        deploy_image = self.image_uri
         if not deploy_image:
             if instance_type is None:
                 raise ValueError(
@@ -179,17 +183,14 @@ class MXNetModel(FrameworkModel):
             str: The appropriate image URI based on the given parameters.
 
         """
-        framework_name = self.__framework_name__
-        if self._is_mms_version():
-            framework_name = "{}-serving".format(framework_name)
-
-        return create_image_uri(
+        return image_uris.retrieve(
+            self._framework_name,
             region_name,
-            framework_name,
-            instance_type,
-            self.framework_version,
-            self.py_version,
+            version=self.framework_version,
+            py_version=self.py_version,
+            instance_type=instance_type,
             accelerator_type=accelerator_type,
+            image_scope="inference",
         )
 
     def _is_mms_version(self):
