@@ -17,21 +17,23 @@ import logging
 import packaging.version
 
 import sagemaker
+from sagemaker import image_uris
+from sagemaker.deserializers import NumpyDeserializer
 from sagemaker.fw_utils import (
-    create_image_uri,
     model_code_key_prefix,
     python_deprecation_warning,
-    empty_framework_version_warning,
+    validate_version_or_image_args,
 )
 from sagemaker.model import FrameworkModel, MODEL_SERVER_WORKERS_PARAM_NAME
 from sagemaker.pytorch import defaults
-from sagemaker.predictor import RealTimePredictor, npy_serializer, numpy_deserializer
+from sagemaker.predictor import Predictor
+from sagemaker.serializers import NumpySerializer
 
 logger = logging.getLogger("sagemaker")
 
 
-class PyTorchPredictor(RealTimePredictor):
-    """A RealTimePredictor for inference against PyTorch Endpoints.
+class PyTorchPredictor(Predictor):
+    """A Predictor for inference against PyTorch Endpoints.
 
     This is able to serialize Python lists, dictionaries, and numpy arrays to
     multidimensional tensors for PyTorch inference.
@@ -49,7 +51,7 @@ class PyTorchPredictor(RealTimePredictor):
                 using the default AWS configuration chain.
         """
         super(PyTorchPredictor, self).__init__(
-            endpoint_name, sagemaker_session, npy_serializer, numpy_deserializer
+            endpoint_name, sagemaker_session, NumpySerializer(), NumpyDeserializer()
         )
 
 
@@ -58,7 +60,7 @@ class PyTorchModel(FrameworkModel):
     ``Endpoint``.
     """
 
-    __framework_name__ = "pytorch"
+    _framework_name = "pytorch"
     _LOWEST_MMS_VERSION = "1.2"
 
     def __init__(
@@ -66,9 +68,9 @@ class PyTorchModel(FrameworkModel):
         model_data,
         role,
         entry_point,
-        image=None,
-        py_version=defaults.PYTHON_VERSION,
         framework_version=None,
+        py_version=None,
+        image_uri=None,
         predictor_cls=PyTorchPredictor,
         model_server_workers=None,
         **kwargs
@@ -87,12 +89,16 @@ class PyTorchModel(FrameworkModel):
                 file which should be executed as the entry point to model
                 hosting. If ``source_dir`` is specified, then ``entry_point``
                 must point to a file located at the root of ``source_dir``.
-            image (str): A Docker image URI (default: None). If not specified, a
-                default image for PyTorch will be used.
-            py_version (str): Python version you want to use for executing your
-                model training code (default: 'py3').
             framework_version (str): PyTorch version you want to use for
-                executing your model training code.
+                executing your model training code. Defaults to None. Required
+                unless ``image_uri`` is provided.
+            py_version (str): Python version you want to use for executing your
+                model training code. Defaults to ``None``. Required unless
+                ``image_uri`` is provided.
+            image_uri (str): A Docker image URI (default: None). If not specified, a
+                default image for PyTorch will be used. If ``framework_version``
+                or ``py_version`` are ``None``, then ``image_uri`` is required. If
+                also ``None``, then a ``ValueError`` will be raised.
             predictor_cls (callable[str, sagemaker.session.Session]): A function
                 to call to create a predictor with an endpoint name and
                 SageMaker ``Session``. If specified, ``deploy()`` returns the
@@ -109,22 +115,18 @@ class PyTorchModel(FrameworkModel):
             :class:`~sagemaker.model.FrameworkModel` and
             :class:`~sagemaker.model.Model`.
         """
-        super(PyTorchModel, self).__init__(
-            model_data, image, role, entry_point, predictor_cls=predictor_cls, **kwargs
-        )
-
+        validate_version_or_image_args(framework_version, py_version, image_uri)
         if py_version == "py2":
             logger.warning(
-                python_deprecation_warning(self.__framework_name__, defaults.LATEST_PY2_VERSION)
+                python_deprecation_warning(self._framework_name, defaults.LATEST_PY2_VERSION)
             )
-
-        if framework_version is None:
-            logger.warning(
-                empty_framework_version_warning(defaults.PYTORCH_VERSION, defaults.LATEST_VERSION)
-            )
-
+        self.framework_version = framework_version
         self.py_version = py_version
-        self.framework_version = framework_version or defaults.PYTORCH_VERSION
+
+        super(PyTorchModel, self).__init__(
+            model_data, image_uri, role, entry_point, predictor_cls=predictor_cls, **kwargs
+        )
+
         self.model_server_workers = model_server_workers
 
     def prepare_container_def(self, instance_type=None, accelerator_type=None):
@@ -142,7 +144,7 @@ class PyTorchModel(FrameworkModel):
             dict[str, str]: A container definition object usable with the
             CreateModel API.
         """
-        deploy_image = self.image
+        deploy_image = self.image_uri
         if not deploy_image:
             if instance_type is None:
                 raise ValueError(
@@ -180,17 +182,14 @@ class PyTorchModel(FrameworkModel):
             str: The appropriate image URI based on the given parameters.
 
         """
-        framework_name = self.__framework_name__
-        if self._is_mms_version():
-            framework_name = "{}-serving".format(framework_name)
-
-        return create_image_uri(
+        return image_uris.retrieve(
+            self._framework_name,
             region_name,
-            framework_name,
-            instance_type,
-            self.framework_version,
-            self.py_version,
+            version=self.framework_version,
+            py_version=self.py_version,
+            instance_type=instance_type,
             accelerator_type=accelerator_type,
+            image_scope="inference",
         )
 
     def _is_mms_version(self):
