@@ -15,13 +15,12 @@ from __future__ import absolute_import
 
 import logging
 
+from sagemaker import image_uris
 from sagemaker.estimator import Framework
-from sagemaker.fw_registry import default_framework_uri
 from sagemaker.fw_utils import (
     framework_name_from_image,
-    get_unsupported_framework_version_error,
-    later_framework_version_warning,
-    python_deprecation_warning,
+    framework_version_from_tag,
+    validate_version_or_image_args,
 )
 from sagemaker.sklearn import defaults
 from sagemaker.sklearn.model import SKLearnModel
@@ -33,16 +32,16 @@ logger = logging.getLogger("sagemaker")
 class SKLearn(Framework):
     """Handle end-to-end training and deployment of custom Scikit-learn code."""
 
-    __framework_name__ = defaults.SKLEARN_NAME
+    _framework_name = defaults.SKLEARN_NAME
 
     def __init__(
         self,
         entry_point,
-        framework_version=defaults.SKLEARN_VERSION,
+        framework_version=None,
+        py_version="py3",
         source_dir=None,
         hyperparameters=None,
-        py_version="py3",
-        image_name=None,
+        image_uri=None,
         **kwargs
     ):
         """This ``Estimator`` executes an Scikit-learn script in a managed
@@ -69,7 +68,13 @@ class SKLearn(Framework):
                 If ``source_dir`` is specified, then ``entry_point``
                 must point to a file located at the root of ``source_dir``.
             framework_version (str): Scikit-learn version you want to use for
-                executing your model training code.
+                executing your model training code. Defaults to ``None``. Required
+                unless ``image_uri`` is provided. List of supported versions:
+                https://github.com/aws/sagemaker-python-sdk#sklearn-sagemaker-estimators
+            py_version (str): Python version you want to use for executing your
+                model training code (default: 'py3'). Currently, 'py3' is the only
+                supported version. If ``None`` is passed in, ``image_uri`` must be
+                provided.
             source_dir (str): Path (absolute, relative or an S3 URI) to a directory
                 with any other training source code dependencies aside from the entry
                 point file (default: None). If ``source_dir`` is an S3 URI, it must
@@ -81,15 +86,18 @@ class SKLearn(Framework):
                 SageMaker. For convenience, this accepts other types for keys
                 and values, but ``str()`` will be called to convert them before
                 training.
-            py_version (str): Python version you want to use for executing your
-                model training code (default: 'py3'). One of 'py2' or 'py3'.
-            image_name (str): If specified, the estimator will use this image
+            image_uri (str): If specified, the estimator will use this image
                 for training and hosting, instead of selecting the appropriate
                 SageMaker official image based on framework_version and
                 py_version. It can be an ECR url or dockerhub image and tag.
+
                 Examples:
                     123.dkr.ecr.us-west-2.amazonaws.com/my-custom-image:1.0
                     custom-image:latest.
+
+                If ``framework_version`` or ``py_version`` are ``None``, then
+                ``image_uri`` is required. If also ``None``, then a ``ValueError``
+                will be raised.
             **kwargs: Additional kwargs passed to the
                 :class:`~sagemaker.estimator.Framework` constructor.
 
@@ -99,50 +107,42 @@ class SKLearn(Framework):
             :class:`~sagemaker.estimator.Framework` and
             :class:`~sagemaker.estimator.EstimatorBase`.
         """
+        validate_version_or_image_args(framework_version, py_version, image_uri)
+        if py_version and py_version != "py3":
+            raise AttributeError(
+                "Scikit-learn image only supports Python 3. Please use 'py3' for py_version."
+            )
+        self.framework_version = framework_version
+        self.py_version = py_version
+
         # SciKit-Learn does not support distributed training or training on GPU instance types.
         # Fail fast.
-        train_instance_type = kwargs.get("train_instance_type")
-        _validate_not_gpu_instance_type(train_instance_type)
+        instance_type = kwargs.get("instance_type")
+        _validate_not_gpu_instance_type(instance_type)
 
-        train_instance_count = kwargs.get("train_instance_count")
-        if train_instance_count:
-            if train_instance_count != 1:
+        instance_count = kwargs.get("instance_count")
+        if instance_count:
+            if instance_count != 1:
                 raise AttributeError(
-                    "Scikit-Learn does not support distributed training. "
-                    "Please remove the 'train_instance_count' argument or set "
-                    "'train_instance_count=1' when initializing SKLearn."
+                    "Scikit-Learn does not support distributed training. Please remove the "
+                    "'instance_count' argument or set 'instance_count=1' when initializing SKLearn."
                 )
+
         super(SKLearn, self).__init__(
             entry_point,
             source_dir,
             hyperparameters,
-            image_name=image_name,
-            **dict(kwargs, train_instance_count=1)
+            image_uri=image_uri,
+            **dict(kwargs, instance_count=1)
         )
 
-        if py_version == "py2":
-            logger.warning(
-                python_deprecation_warning(self.__framework_name__, defaults.LATEST_PY2_VERSION)
-            )
-
-        self.py_version = py_version
-
-        if framework_version in defaults.SKLEARN_SUPPORTED_VERSIONS:
-            self.framework_version = framework_version
-        else:
-            raise ValueError(
-                get_unsupported_framework_version_error(
-                    self.__framework_name__, framework_version, defaults.SKLEARN_SUPPORTED_VERSIONS
-                )
-            )
-
-        if framework_version != defaults.SKLEARN_LATEST_VERSION:
-            logger.warning(later_framework_version_warning(defaults.SKLEARN_LATEST_VERSION))
-
-        if image_name is None:
-            image_tag = "{}-{}-{}".format(framework_version, "cpu", py_version)
-            self.image_name = default_framework_uri(
-                SKLearn.__framework_name__, self.sagemaker_session.boto_region_name, image_tag
+        if image_uri is None:
+            self.image_uri = image_uris.retrieve(
+                SKLearn._framework_name,
+                self.sagemaker_session.boto_region_name,
+                version=self.framework_version,
+                py_version=self.py_version,
+                instance_type=instance_type,
             )
 
     def create_model(
@@ -188,22 +188,19 @@ class SKLearn(Framework):
             object. See :func:`~sagemaker.sklearn.model.SKLearnModel` for full details.
         """
         role = role or self.role
+        kwargs["name"] = self._get_or_create_name(kwargs.get("name"))
 
-        if "image" not in kwargs:
-            kwargs["image"] = self.image_name
+        if "image_uri" not in kwargs:
+            kwargs["image_uri"] = self.image_uri
 
         if "enable_network_isolation" not in kwargs:
             kwargs["enable_network_isolation"] = self.enable_network_isolation()
 
-        if "name" not in kwargs:
-            kwargs["name"] = self._current_job_name
-
         return SKLearnModel(
             self.model_data,
             role,
-            entry_point or self.entry_point,
+            entry_point or self._model_entry_point(),
             source_dir=(source_dir or self._model_source_dir()),
-            enable_cloudwatch_metrics=self.enable_cloudwatch_metrics,
             container_log_level=self.container_log_level,
             code_location=self.code_location,
             py_version=self.py_version,
@@ -223,28 +220,38 @@ class SKLearn(Framework):
         Args:
             job_details: the returned job details from a describe_training_job
                 API call.
-            model_channel_name:
+            model_channel_name (str): Name of the channel where pre-trained
+                model data will be downloaded (default: None).
 
         Returns:
             dictionary: The transformed init_params
         """
-        init_params = super(SKLearn, cls)._prepare_init_params_from_job_description(job_details)
+        init_params = super(SKLearn, cls)._prepare_init_params_from_job_description(
+            job_details, model_channel_name
+        )
+        image_uri = init_params.pop("image_uri")
+        framework, py_version, tag, _ = framework_name_from_image(image_uri)
 
-        image_name = init_params.pop("image")
-        framework, py_version, _, _ = framework_name_from_image(image_name)
+        if tag is None:
+            framework_version = None
+        else:
+            framework_version = framework_version_from_tag(tag)
+        init_params["framework_version"] = framework_version
         init_params["py_version"] = py_version
 
-        if framework and framework != cls.__framework_name__:
-            training_job_name = init_params["base_job_name"]
-            raise ValueError(
-                "Training job: {} didn't use image for requested framework".format(
-                    training_job_name
-                )
-            )
         if not framework:
             # If we were unable to parse the framework name from the image it is not one of our
             # officially supported images, in this case just add the image to the init params.
-            init_params["image_name"] = image_name
+            init_params["image_uri"] = image_uri
+            return init_params
+
+        if framework and framework != "scikit-learn":
+            raise ValueError(
+                "Training job: {} didn't use image for requested framework".format(
+                    job_details["TrainingJobName"]
+                )
+            )
+
         return init_params
 
 
