@@ -13,28 +13,25 @@
 """Placeholder docstring"""
 from __future__ import absolute_import
 
-from sagemaker import Model, RealTimePredictor, Session
-from sagemaker.content_types import CONTENT_TYPE_CSV
-from sagemaker.fw_registry import registry
-from sagemaker.predictor import csv_serializer
+from sagemaker import Model, Predictor, Session, image_uris
+from sagemaker.serializers import CSVSerializer
 
 framework_name = "sparkml-serving"
-repo_name = "sagemaker-sparkml-serving"
 
 
-class SparkMLPredictor(RealTimePredictor):
+class SparkMLPredictor(Predictor):
     """Performs predictions against an MLeap serialized SparkML model.
 
     The implementation of
-    :meth:`~sagemaker.predictor.RealTimePredictor.predict` in this
-    `RealTimePredictor` requires a json as input. The input should follow the
+    :meth:`~sagemaker.predictor.Predictor.predict` in this
+    `Predictor` requires a json as input. The input should follow the
     json format as documented.
 
     ``predict()`` returns a csv output, comma separated if the output is a
     list.
     """
 
-    def __init__(self, endpoint, sagemaker_session=None):
+    def __init__(self, endpoint_name, sagemaker_session=None):
         """Initializes a SparkMLPredictor which should be used with SparkMLModel
         to perform predictions against SparkML models serialized via MLeap. The
         response is returned in text/csv format which is the default response
@@ -49,10 +46,9 @@ class SparkMLPredictor(RealTimePredictor):
         """
         sagemaker_session = sagemaker_session or Session()
         super(SparkMLPredictor, self).__init__(
-            endpoint=endpoint,
+            endpoint_name=endpoint_name,
             sagemaker_session=sagemaker_session,
-            serializer=csv_serializer,
-            content_type=CONTENT_TYPE_CSV,
+            serializer=CSVSerializer(),
         )
 
 
@@ -94,10 +90,10 @@ class SparkMLModel(Model):
         # For local mode, sagemaker_session should be passed as None but we need a session to get
         # boto_region_name
         region_name = (sagemaker_session or Session()).boto_region_name
-        image = "{}/{}:{}".format(registry(region_name, framework_name), repo_name, spark_version)
+        image_uri = image_uris.retrieve(framework_name, region_name, version=spark_version)
         super(SparkMLModel, self).__init__(
+            image_uri,
             model_data,
-            image,
             role,
             predictor_cls=SparkMLPredictor,
             sagemaker_session=sagemaker_session,
