@@ -16,17 +16,19 @@ from __future__ import absolute_import
 import logging
 
 import sagemaker
+from sagemaker import image_uris
+from sagemaker.deserializers import CSVDeserializer
 from sagemaker.fw_utils import model_code_key_prefix
-from sagemaker.fw_registry import default_framework_uri
 from sagemaker.model import FrameworkModel, MODEL_SERVER_WORKERS_PARAM_NAME
-from sagemaker.predictor import RealTimePredictor, npy_serializer, csv_deserializer
+from sagemaker.predictor import Predictor
+from sagemaker.serializers import LibSVMSerializer
 from sagemaker.xgboost.defaults import XGBOOST_NAME
 
 logger = logging.getLogger("sagemaker")
 
 
-class XGBoostPredictor(RealTimePredictor):
-    """A RealTimePredictor for inference against XGBoost Endpoints.
+class XGBoostPredictor(Predictor):
+    """A Predictor for inference against XGBoost Endpoints.
 
     This is able to serialize Python lists, dictionaries, and numpy arrays to xgb.DMatrix
      for XGBoost inference."""
@@ -42,14 +44,14 @@ class XGBoostPredictor(RealTimePredictor):
                 chain.
         """
         super(XGBoostPredictor, self).__init__(
-            endpoint_name, sagemaker_session, npy_serializer, csv_deserializer
+            endpoint_name, sagemaker_session, LibSVMSerializer(), CSVDeserializer()
         )
 
 
 class XGBoostModel(FrameworkModel):
     """An XGBoost SageMaker ``Model`` that can be deployed to a SageMaker ``Endpoint``."""
 
-    __framework_name__ = XGBOOST_NAME
+    _framework_name = XGBOOST_NAME
 
     def __init__(
         self,
@@ -57,7 +59,7 @@ class XGBoostModel(FrameworkModel):
         role,
         entry_point,
         framework_version,
-        image=None,
+        image_uri=None,
         py_version="py3",
         predictor_cls=XGBoostPredictor,
         model_server_workers=None,
@@ -74,10 +76,10 @@ class XGBoostModel(FrameworkModel):
             entry_point (str): Path (absolute or relative) to the Python source file which should
                 be executed  as the entry point to model hosting. If ``source_dir`` is specified,
                 then ``entry_point`` must point to a file located at the root of ``source_dir``.
-            image (str): A Docker image URI (default: None). If not specified, a default image for
-                XGBoos will be used.
+            image_uri (str): A Docker image URI (default: None). If not specified, a default image
+                for XGBoost is be used.
             py_version (str): Python version you want to use for executing your model training code
-                (default: 'py2').
+                (default: 'py3').
             framework_version (str): XGBoost version you want to use for executing your model
                 training code.
             predictor_cls (callable[str, sagemaker.session.Session]): A function to call to create
@@ -95,12 +97,9 @@ class XGBoostModel(FrameworkModel):
             :class:`~sagemaker.model.Model`.
         """
         super(XGBoostModel, self).__init__(
-            model_data, image, role, entry_point, predictor_cls=predictor_cls, **kwargs
+            model_data, image_uri, role, entry_point, predictor_cls=predictor_cls, **kwargs
         )
 
-        if py_version == "py2":
-            raise AttributeError("XGBoost container does not support Python 2, please use Python 3")
-
         self.py_version = py_version
         self.framework_version = framework_version
         self.model_server_workers = model_server_workers
@@ -119,7 +118,7 @@ class XGBoostModel(FrameworkModel):
         Returns:
             dict[str, str]: A container definition object usable with the CreateModel API.
         """
-        deploy_image = self.image
+        deploy_image = self.image_uri
         if not deploy_image:
             deploy_image = self.serving_image_uri(
                 self.sagemaker_session.boto_region_name, instance_type
@@ -134,17 +133,21 @@ class XGBoostModel(FrameworkModel):
             deploy_env[MODEL_SERVER_WORKERS_PARAM_NAME.upper()] = str(self.model_server_workers)
         return sagemaker.container_def(deploy_image, self.model_data, deploy_env)
 
-    def serving_image_uri(self, region_name, instance_type):  # pylint: disable=unused-argument
+    def serving_image_uri(self, region_name, instance_type):
         """Create a URI for the serving image.
 
         Args:
             region_name (str): AWS region where the image is uploaded.
-            instance_type (str): SageMaker instance type. This parameter is unused because
-                XGBoost supports only CPU.
+            instance_type (str): SageMaker instance type. Must be a CPU instance type.
 
         Returns:
             str: The appropriate image URI based on the given parameters.
-
         """
-        image_tag = "{}-{}-{}".format(self.framework_version, "cpu", self.py_version)
-        return default_framework_uri(self.__framework_name__, region_name, image_tag)
+        return image_uris.retrieve(
+            self._framework_name,
+            region_name,
+            version=self.framework_version,
+            py_version=self.py_version,
+            instance_type=instance_type,
+            image_scope="inference",
+        )
